Crate mathquill_js_sys

Crate mathquill_js_sys 

MathQuill JS-sys

Raw bindings to the MathQuill library. You probably don’t want this library, but you do want mathquill-js which provides idiomatic Rust bindings to MathQuill through this library. You need to load the JQuery JS library and the MathQuill JS library before using this crate, download from their github releases page and a copy of jQuery (e.g. here). You will then need to include <script> tags to load them. See the MathQuill documentation for more details

Structs

Config
This is an owned, abstracted representation of the configuartion options supported by MathQuill. Dropping this struct invalidates callbacks on fields mounted by this config, see Handlers.
Handlers
https://docs.mathquill.com/en/latest/Config/#handlers
MathField
MathQuill
https://docs.mathquill.com/en/latest/Api_Methods/#api-methods
StaticMath