pub struct Config<MathField> {
pub space_behaves_like_tab: Option<bool>,
pub handlers: Handlers<MathField>,
}Expand description
This is an owned, abstracted representation of the configuartion options
supported by MathQuill.
Dropping this struct invalidates callbacks on fields mounted by this config,
see Handlers.
Use Config::get_js_value to pass through the Wasm ABI interface
Fields
space_behaves_like_tab: Option<bool>handlers: Handlers<MathField>Implementations